==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_vulkan_window_swap_chain_based.js <==
var class_ogre_1_1_vulkan_window_swap_chain_based =
[
    [ "Backend", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281", [
      [ "BackendX11", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259", null ]
    ] ],
    [ "SwapchainStatus", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973", [
      [ "SwapchainAcquired", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada", null ],
      [ "SwapchainUsedInRendering", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24", null ],
      [ "SwapchainPendingSwap", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7", null ],
      [ "SwapchainReleased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d", null ]
    ] ],
    [ "VulkanWindowSwapChainBased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad2fb682ca82f8ea974a64cfef5c622b4", null ],
    [ "~VulkanWindowSwapChainBased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a1f2003e719c4539cf39e2727caf0ecca", null ],
    [ "_initialize", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a95c79431ef5e02a234b0119e288324ee", null ],
    [ "_initialize", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a1ddfa4bf1c7c366ad92a8a6c93aeec8c", null ],
    [ "_setDevice", "class_ogre_1_1_vulkan_window_swap_chain_based.html#acd46202d3fd921f029d029fa2f5ed59b", null ],
    [ "_setPrimary", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161", null ],
    [ "_setVisible", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa7ac08a06bc2a2c4d2638a844f6b4351", null ],
    [ "_swapBuffers", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a319d7bba3d2a578b0c846f0b419692ff", null ],
    [ "acquireNextSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a9af2d2b27cf6a53c60aca59598f631b2", null ],
    [ "chooseSurfaceFormat", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d6f1accac3551566dc3de3a44cfc9ac", null ],
    [ "createSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac4782abeb9698a9d72469dde923bc714", null ],
    [ "destroy", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a85f87e6c41a86bde631a893d0f1c0b26", null ],
    [ "destroySwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a123eb1645adc5c9f7b7f85b65d33f5ae", null ],
    [ "getBorderless", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a67ba7307754a41632bb41c383191bba7", null ],
    [ "getCustomAttribute", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a12e5ec4a26b5d90aeb1b67ffe61bdeb0", null ],
    [ "getDepthBuffer", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c", null ],
    [ "getFrequencyDenominator", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a70cfe4412cfa68a9423854fc1b19872e", null ],
    [ "getFrequencyNumerator", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65", null ],
    [ "getHeight", "class_ogre_1_1_vulkan_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec", null ],
    [ "getImageAcquiredSemaphore", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a39e1b46f2145825d0620bc2ea50f6567", null ],
    [ "getMetrics", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4", null ],
    [ "getNumSwapchains", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a0e8ae8b1cc1827631a7487ac7aff4256", null ],
    [ "getPixelFormat", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75", null ],
    [ "getRequestedHeightPt", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d", null ],
    [ "getRequestedWidthPt", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c", null ],
    [ "getSampleDescription", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78", null ],
    [ "getStencilBuffer", "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4", null ],
    [ "getSwapchainImage", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a3766e755970279f575ec9e80db978b2d", null ],
    [ "getTexture", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a75261d46e5f123e31ab4f889b8788e5f", null ],
    [ "getTitle", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a3b1af2a3ccebacfad34e1c5c2eb99d49", null ],
    [ "getViewPointToPixelScale", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a12411d378aa0623e29287964eeb261c4", null ],
    [ "getVSync", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a84739cd779700fa8d7991c9cf11c289d", null ],
    [ "getVSyncInterval", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a6acbc757e5f5b091aa51022e4cb382a4", null ],
    [ "getWidth", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a814de6b1529bba5f7aa80ea3ac537ae1", null ],
    [ "isClosed", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aecf38609606a498bc552a6cbbd5b3c38", null ],
    [ "isFocused", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a462859aeb6b4db7290622623dae2a6a4", null ],
    [ "isFullscreen", "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4", null ],
    [ "isHidden", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a4134fbf0e0302588fd92f7a3d9bd852c", null ],
    [ "isMultisample", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a22779bbfb123c76e922942ba876e330a", null ],
    [ "isPrimary", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5", null ],
    [ "isVisible", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a14c0ef3312945158ad042463bef69e74", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "parseSharedParams", "class_ogre_1_1_vulkan_window_swap_chain_based.html#adfbd4f24b29343958aba5af0708a0683", null ],
    [ "reposition", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a5d39c20103e51bd756ebc97956b3c98d", null ],
    [ "requestFullscreenSwitch", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a2d5423c38fb53d7346a00c0e7e582347", null ],
    [ "requestResolution", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a1284a6c13adf9c244e4dcc2f973d7749", null ],
    [ "setBorderless", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa6ee76edb7111f8feefbb1f73aae50be", null ],
    [ "setFocused", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7df3603f7918dcb9af4e6c031d0b7fb9", null ],
    [ "setFsaa", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a0f7e59347f6a688da34e9a759e92aa1a", null ],
    [ "setHidden", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a80738edbd5cf6649ca46331426137ccf", null ],
    [ "setTitle", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042", null ],
    [ "setVSync", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a6e731d4414d454716620f0b401b9c823", null ],
    [ "swapBuffers", "class_ogre_1_1_vulkan_window_swap_chain_based.html#af574272c60f388e4c4712fa5d358ef7a", null ],
    [ "wantsToGoFullscreen", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3", null ],
    [ "wantsToGoWindowed", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7", null ],
    [ "windowMovedOrResized", "class_ogre_1_1_vulkan_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea", null ],
    [ "mClosed", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a09ff80100ca52995038ce8b404330c24", null ],
    [ "mLowestLatencyVSync", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa562105b8ede44dd4bba7704ffcf763c", null ],
    [ "mRebuildingSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a452c19b6161f1ae310dfd92b026f7ed9", null ],
    [ "mSuboptimal", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a26e48774201b2ea86d0928ffdda4f583", null ],
    [ "mSurfaceKHR", "class_ogre_1_1_vulkan_window_swap_chain_based.html#afb956dde983e96a95394aa55215c55da", null ],
    [ "mSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7f7db089d78132c7a62c0fd0c2344185", null ],
    [ "mSwapchainImages", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7359904108c9c7ac2cd3a3c1fdd891ad", null ],
    [ "mSwapchainSemaphore", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a0e960d623b65169a6ccff4b0815c8751", null ],
    [ "mSwapchainStatus", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a24faacfa4584e67e19bb04cf11d83323", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_vulkan_window_swap_chain_based.js <==
var class_ogre_1_1_vulkan_window_swap_chain_based =
[
    [ "Backend", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281", [
      [ "BackendX11", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259", null ]
    ] ],
    [ "SwapchainStatus", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973", [
      [ "SwapchainAcquired", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada", null ],
      [ "SwapchainUsedInRendering", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24", null ],
      [ "SwapchainPendingSwap", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7", null ],
      [ "SwapchainReleased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d", null ]
    ] ],
    [ "VulkanWindowSwapChainBased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad2fb682ca82f8ea974a64cfef5c622b4", null ],
    [ "~VulkanWindowSwapChainBased", "class_ogre_1_1_vulkan_window_swap_chain_based.html#acc1f3768bdf583d8818aa6fe8c5453b2", null ],
    [ "_swapBuffers", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a319d7bba3d2a578b0c846f0b419692ff", null ],
    [ "acquireNextSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab48fc2ff56a29b65220b8c7a69eef8d4", null ],
    [ "canDownloadData", "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad337e8d5f7a28e608259a18269694bf6", null ],
    [ "chooseSurfaceFormat", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d6f1accac3551566dc3de3a44cfc9ac", null ],
    [ "createSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a881dd6b5984a497d0b554b0eb14793e4", null ],
    [ "destroy", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7d713cd086e916722a1dd2227b2a8071", null ],
    [ "destroySwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a52c3e9ef70853f880c393c81e7394b5c", null ],
    [ "getCustomAttribute", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a5a92d312fe89d7ca06565d0fb7554b30", null ],
    [ "getImageAcquiredSemaphore", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a62633b1e5220c2884e44b30a78d1183e", null ],
    [ "getNumSwapchains", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a811d6c6130306f30a3bfcbf9d70fa39b", null ],
    [ "getSwapchainImage", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a3766e755970279f575ec9e80db978b2d", null ],
    [ "isClosed", "class_ogre_1_1_vulkan_window_swap_chain_based.html#afb590228fc657851f83cfba4784e64a9", null ],
    [ "parseSharedParams", "class_ogre_1_1_vulkan_window_swap_chain_based.html#adfbd4f24b29343958aba5af0708a0683", null ],
    [ "setVSync", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a916940a0741df1e54066f9890422c741", null ],
    [ "setWantsToDownload", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a41ca2fb7efc73c6911f920c6310b536e", null ],
    [ "swapBuffers", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a4c27223d721aafa46c86d552a9055cfb", null ],
    [ "mCanDownloadData", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a348e5a12f2b856e2a53c835d9ee40ba1", null ],
    [ "mClosed", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a09ff80100ca52995038ce8b404330c24", null ],
    [ "mEnablePreTransform", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a747bcc89c2d87d95cd075609ff55d6a3", null ],
    [ "mLowestLatencyVSync", "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa562105b8ede44dd4bba7704ffcf763c", null ],
    [ "mRebuildingSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a452c19b6161f1ae310dfd92b026f7ed9", null ],
    [ "mSuboptimal", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a26e48774201b2ea86d0928ffdda4f583", null ],
    [ "mSurfaceKHR", "class_ogre_1_1_vulkan_window_swap_chain_based.html#afb956dde983e96a95394aa55215c55da", null ],
    [ "mSwapchain", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7f7db089d78132c7a62c0fd0c2344185", null ],
    [ "mSwapchainImages", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a7359904108c9c7ac2cd3a3c1fdd891ad", null ],
    [ "mSwapchainSemaphore", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a0e960d623b65169a6ccff4b0815c8751", null ],
    [ "mSwapchainStatus", "class_ogre_1_1_vulkan_window_swap_chain_based.html#a24faacfa4584e67e19bb04cf11d83323", null ]
];
